@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2016-2021
+# Copyright Louis Paternault 2016-2022
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,6 +53,9 @@ tells what to do when adding a subcommand that already exists:
     it. This does not seem to be documented, but it seems that the parser then
     contains two subcommands with the same name.
 
+    .. deprecated:: 1.3.0
+       Python3.11 raises an error if two subparsers have the same name.
+
 
 .. _importerror:
 
@@ -153,7 +156,6 @@ Here are all the :class:`_SubCommandsDispatch` commands to define subcommands.
     .. automethod:: _SubCommandsDispatch.add_prefix_executables
 """
 
-from argparse import *  # pylint: disable=wildcard-import
 import argparse
 import enum
 import importlib
@@ -164,13 +166,19 @@ import runpy
 import subprocess
 import sys
 import types
+from argparse import *  # pylint: disable=wildcard-import
 
 import pkg_resources
 
-VERSION = "1.2.0"
+VERSION = "1.3.0"
 __AUTHOR__ = "Louis Paternault (spalax@gresille.org)"
-__COPYRIGHT__ = "(C) 2017-2021 Louis Paternault. GNU GPL 3 or later."
-__all__ = argparse.__all__ + ["ERROR", "IGNORE", "DOUBLE", "RAISE"]
+__COPYRIGHT__ = "(C) 2017-2022 Louis Paternault. GNU GPL 3 or later."
+
+if sys.version_info < (3, 11):
+    __all__ = argparse.__all__ + ["ERROR", "IGNORE", "DOUBLE", "RAISE"]
+else:
+    __all__ = argparse.__all__ + ["ERROR", "IGNORE", "RAISE"]
+
 
 ################################################################################
 # Constants
@@ -184,16 +192,12 @@ class _Constants(enum.IntEnum):
     DOUBLE = enum.auto()
     RAISE = enum.auto()
 
-    def __repr__(self):
-        # Pylint (2.5.0) is wrong!
-        # pylint: disable=invalid-repr-returned
-        return self.name
-
 
 ERROR = _Constants.ERROR
 IGNORE = _Constants.IGNORE
-DOUBLE = _Constants.DOUBLE
 RAISE = _Constants.RAISE
+if sys.version_info < (3, 11):
+    DOUBLE = _Constants.DOUBLE
 
 ################################################################################
 # Misc utilities
@@ -297,13 +301,21 @@ class _SubCommandsDispatch(
             already defined, this function returns nothing (`None`). Otherwise,
             it returns an :class:`ArgumentParser` object.
 
-        :param ondouble: See :ref:`ondouble`. Default is :data:`DOUBLE`.
+        :param ondouble: See :ref:`ondouble`. Default is :data:`ERROR`
+            (default was :data:`DOUBLE` before version 1.3.0).
         :return: A :class:`ArgumentParser` object, or `None`.
         :raises: A :class:`ValueError` exception, if argument `ondouble` is
             :data:`ERROR`, and command name already exists.
+
+        .. versionchanged:: 1.3.0
+           Before version 1.3.0, default value for ``ondouble`` was :data:`DOUBLE`.
+           It is now :data:`ERROR`.
         """
         # pylint: disable=arguments-differ
-        ondouble = kwargs.pop("ondouble", DOUBLE)
+        if sys.version_info < (3, 11):
+            ondouble = kwargs.pop("ondouble", DOUBLE)
+        else:
+            ondouble = kwargs.pop("ondouble", ERROR)
         if args[0] in self._name_dispatcher_map:
             if ondouble == IGNORE:
                 return
@@ -333,10 +345,10 @@ class _SubCommandsDispatch(
             if ondouble == ERROR:
                 raise ValueError(f"Subcommand '{command}' is already defined.")
             if ondouble == DOUBLE:
-                pass
+                self.add_parser(command, help=help, ondouble=DOUBLE)
         else:
             self._name_dispatcher_map[command] = _make_bin_executable(executable)
-        self.add_parser(command, help=help, ondouble=DOUBLE)
+            super().add_parser(command, help=help)
 
     def add_pattern_executables(self, pattern, *, path=None, ondouble=IGNORE):
         """Add all the executables in path matching the regular expression.
@@ -386,7 +398,7 @@ class _SubCommandsDispatch(
         :param ondouble: See :ref:`ondouble`. Default is :data:`IGNORE`.
         """
         return self.add_pattern_executables(
-            fr"^{prefix}(?P<command>.*)$", path=path, ondouble=ondouble
+            rf"^{prefix}(?P<command>.*)$", path=path, ondouble=ondouble
         )
 
     def add_function(self, function, command=None, *, help=None, ondouble=ERROR):
@@ -417,10 +429,10 @@ class _SubCommandsDispatch(
             if ondouble == ERROR:
                 raise ValueError(f"Subcommand '{command}' is already defined.")
             if ondouble == DOUBLE:
-                pass
+                self.add_parser(command, help=help, ondouble=DOUBLE)
         else:
             self._name_dispatcher_map[command] = function
-        self.add_parser(command, help=help, ondouble=DOUBLE)
+            super().add_parser(command, help=help)
 
     def add_module(
         self,
@@ -513,10 +525,10 @@ class _SubCommandsDispatch(
             if ondouble == ERROR:
                 raise ValueError(f"Subcommand '{command}' is already defined.")
             if ondouble == DOUBLE:
-                pass
+                self.add_parser(command, help=help, ondouble=DOUBLE)
         else:
             self._name_dispatcher_map[command] = _make_module_executable(modulename)
-        self.add_parser(command, help=help, ondouble=DOUBLE)
+            super().add_parser(command, help=help)
 
     def add_submodules(self, module, *, ondouble=IGNORE, onerror=IGNORE):
         """Add subcommands matching `module`'s submodules.
