@@ -1,4 +1,4 @@
-# Copyright 2020 Louis Paternault
+# Copyright 2020-2022 Louis Paternault
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,13 +15,12 @@
 
 """Tests of the add_executable(), add_prefix_executables(), add_pattern_executables() methods."""
 
-from unittest.mock import patch
 import importlib
+from unittest.mock import patch
 
 import argdispatch
 
-from . import TestArgparse
-from . import pythonpath
+from . import TestArgparse, pythonpath
 
 
 class _MockEntrypointFunction:
