@@ -1,4 +1,4 @@
-# Copyright 2016-2020 Louis Paternault
+# Copyright 2016-2022 Louis Paternault
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
 
 import argdispatch
 
-from . import TestArgparse
-from . import pythonpath
+from . import TestArgparse, pythonpath
 
 
 class TestModule(TestArgparse):
@@ -182,7 +181,11 @@ class TestModule(TestArgparse):
         sub = parser.add_subparsers()
 
         #  pylint: disable=import-outside-toplevel, import-error, multiple-imports
-        import withinit, withinit2, withoutinit, withmain, notapackage
+        import notapackage
+        import withinit
+        import withinit2
+        import withmain
+        import withoutinit
 
         with self.subTest():
             sub.add_module(withmain, forcemain=True)
