@@ -1,4 +1,4 @@
-# Copyright 2016-2021 Louis Paternault
+# Copyright 2016-2022 Louis Paternault
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,11 +16,11 @@
 """Test of various options"""
 
 import sys
+import unittest
 
 import argdispatch
 
-from . import TestArgparse
-from . import binpath, pythonpath
+from . import TestArgparse, binpath, pythonpath
 
 
 def function_foo(args):
@@ -76,6 +76,7 @@ class TestOndouble(TestArgparse):
                 with self.assertExit(0):
                     parser.parse_args("--help".split())
 
+    @unittest.skipIf(sys.version_info > (3, 11, 0), "Raise an error with Python>=3.11")
     @pythonpath("pythonpath1")
     @binpath("binpath1")
     def test_double(self):
